@@ -12,6 +12,7 @@ class TestProviderAccount(BaseTestCase):
         self.provider_acc_id = 1
 
     def test_read_update(self):
+        # TODO: add client for provider
         provider_acc = ProviderAccount(api_client=test_api_client)
         # provider_acc.id = self.provider_acc_id
         provider_acc.application = self.application_id
@@ -28,3 +29,13 @@ class TestProviderAccount(BaseTestCase):
         provider_acc.update()
         assert provider_acc.login == new_value
 
+
+
+
+class TestProviderAccountList():
+    def setup(self):
+        self.provider_account_list = ProviderAccountList(api_client=test_api_client)
+
+    def test_list(self):
+        assert isinstance(self.provider_account_list.list(), list)
+
