@@ -18,7 +18,6 @@ class TestProviderAccount():
         user.first_name = 'first'
         user.last_name = 'last'
         user.create()
-        print(user.id)
         user.read()
         assert user.username != None
         assert user.email != None
@@ -29,3 +28,11 @@ class TestProviderAccount():
         assert user.last_name == new_value
 
         user.destroy()
+
+
+class TestUserList():
+    def setup(self):
+        self.user_list = UserList(api_client=test_api_client)
+
+    def test_list(self):
+        assert isinstance(self.user_list.list(), list)
